@@ -5,8 +5,10 @@
 #include <termio.h>
 #include <stdlib.h>
 #include <sys/types.h>
+#include <string.h>
 
-#define BUFF_SIZE 1024
+#define BUFF_SIZE   1024
+#define STRLEN(str) (sizeof(str)-1)
 
 void 
 print_bar(void)
@@ -14,11 +16,15 @@ print_bar(void)
   printf("\n--------\n\n");
 }
 
-void
-print_file(const char *fname)
+int
+print_file(const char *fpath)
 {
-  FILE *msg;
-  if (msg=fopen(fname,"r"))
+  FILE       *msg=0;
+  const char *fname;
+  if (fname=strrchr(fpath,'/')) ++fname; else fname=fpath;
+  if (strncmp(fname,FNAME_PREFIX,STRLEN(FNAME_PREFIX)))
+    printf("Inadequate name for issue file: '%s'\n",fpath);
+  else if (msg=fopen(fpath,"r"))
   {
     static char buff[BUFF_SIZE];
     size_t len;
@@ -26,8 +32,10 @@ print_file(const char *fname)
       fwrite(buff,sizeof(char),len,stdout);
     fclose(msg);
   }
-  else printf("Cannot open file with message: '%s'\n",fname);
+  else
+    printf("Cannot open file with message: '%s'\n",fpath);
   print_bar();
+  return msg!=0;
 }
 
 int 
@@ -54,13 +62,13 @@ main(int argc, char **argv)
 {
   char          c, *home_dir;
   struct termio tbuf;
-  int           i;
+  int           i, n=0;
   home_dir=getenv("HOME");
   if (!home_dir || !*home_dir) home_dir="/";
   if (chdir(home_dir)) chdir("/");
   print_bar();
-  if (argc>1) for (i=1; i<argc; ++i) print_file(argv[i]);
-  else print_file(STD_ISSUE_FILE);
+  for (i=1; i<argc; ++i) n+=print_file(argv[i]);
+  if (!n) print_file(STD_ISSUE_FILE);
   printf("--- press any key to disconnect ---\n");
   fflush(0);
   termsetraw(0,&tbuf);
